@@ -1,4 +1,5 @@
 from pathlib import Path
+import os
 
 import nox
 
@@ -23,7 +24,14 @@ def session(default=True, **kwargs):
 @session(python=["3.8", "3.9", "3.10", "3.11", "pypy3"])
 def tests(session):
     session.install("pytest", ROOT)
-    session.run("pytest", "--verbosity=3")
+    env = dict(os.environ, PYTHONWARNDEFAULTENCODING="1")
+    session.run("pytest", "--verbosity=3", "--pythonwarnings=error", env=env)
+
+
+@session()
+def audit(session):
+    session.install("pip-audit", ROOT)
+    session.run("python", "-m", "pip_audit")
 
 
 @session(tags=["build"])
@@ -38,20 +46,13 @@ def readme(session):
     session.install("build", "twine")
     tmpdir = session.create_tmp()
     session.run("python", "-m", "build", ROOT, "--outdir", tmpdir)
-    session.run("python", "-m", "twine", "check", tmpdir + "/*")
+    session.run("python", "-m", "twine", "check", "--strict", tmpdir + "/*")
 
 
 @session(tags=["style"])
 def style(session):
-    session.install(
-        "flake8",
-        "flake8-broken-line",
-        "flake8-bugbear",
-        "flake8-commas",
-        "flake8-quotes",
-        "flake8-tidy-imports",
-    )
-    session.run("python", "-m", "flake8", PACKAGE, __file__)
+    session.install("ruff")
+    session.run("ruff", "check", ROOT)
 
 
 @session()
